 !     VARIABLES ::rdata, fdata
!  1:rho_0 dr_x
!  2:rho_0 dr_y
!  3:rho_0 dr_z
!  4:rho_0 drdot_x
!  5:rho_0 drdot_y
!  6:rho_0 drdot_z        
!     rdata: contains their real coefficients
!     fdata: contains their fourier coefficients

!top and bottom rows are outside computational domain.

! dr
!  1: dr_x
!  2: dr_y
!  3: dr_z
!  4: drdot_x
!  5: drdot_y
!  6: drdot_z        


! rPress    Pressure
! fPress
! rRho      Density
! frho
! rdB       Magnetic perturbation      
! fdB        
! rdU       Velocity perturbation 
! fdU
! rLor        Lorentz force
! fLor       
! rInertia    U_0 terms
! fInertia   




!      COEFFICIENTS ::c(:,:,:,i)
!  1  rho_0
!  2  Grad rho_0_x
!  3  Grad rho_0_y
!  4  Grad rho_0_z
!  5  Gamma_1 * Press_0 / rho_0
!  6  [Gamma_1 * Press_0 * (nabla rho_0) /rho_0 -(nabla Press_0)]_x
!  7  [Gamma_1 * Press_0 * (nabla rho_0) /rho_0 -(nabla Press_0)]_y
!  8  [Gamma_1 * Press_0 * (nabla rho_0) /rho_0 -(nabla Press_0)]_z
!  9  [(nabla Press_0)]_x
! 10  [(nabla Press_0)]_y
! 11  [(nabla Press_0)]_z
! 12  1 / rho_0
! 13  [g / rho_0]
! 14  g
! 15  B_0_x
! 16  B_0_y
! 17  B_0_z
! 18  J_0_x
! 19  J_0_y
! 20  J_0_z
! 21  U_0_x
! 22  U_0_y
! 23  U_0_z
! 24  d/dx U_0_x
! 25  d/dx U_0_y
! 26  d/dx U_0_z
! 27  d/dy U_0_x
! 28  d/dy U_0_y
! 29  d/dy U_0_z
! 30  d/dz U_0_x
! 31  d/dz U_0_y
! 32  d/dz U_0_z
! 33  U_0_x/rho_0
! 34  U_0_y/rho_0
! 35  U_0_z/rho_0
!BC stuff
! 36  Gamma_1 Press_0
! 37 B_0_x/B_0_z (with min(abs(B0))=1e-6
! 38 B_0_x/B_0_z (with min(abs(B0))=1e-6)
! 39 d/dx [Press_0 +(B_x0^2+B_y0^2-B_z0^2)/(8 pi)]
! 40 d/dx [Press_0 +(B_x0^2+B_y0^2-B_z0^2)/(8 pi)]
! 41 d/dx [Press_0 +(B_x0^2+B_y0^2-B_z0^2)/(8 pi)]


!    TEMPORARY VARIABLES:: 

! fvtemp   (a temporary storage are, FS, vector)
! rvtemp   (a temporary storage are, RS, vector)
 

! AUXILLARY QUANTITIES
!     t:time, 
!     dt: time step, fixed 
!     nx,ny,nz: number of elements in x,y, & z directions
!     ider: array for which multiplication in FS = derivative

! SUBROUTINES
! initialize : sets up the derivatives in FS
! initfftw   : initializes FFT calls
! setupcoeff : loads the coefficients array
! input      : loads the Initial Condition
! derivs     : evaluates RHS of the pde's
! output     : outputs RS variables to files. 

!functions   :
! ddx        : differentiation wrt x in FS
! ddy        : differentiation wrt y in RS
! ddz        : differentiation wrt z in FS


!EXTERNAL PROGRAMS
!makecoeff         : takes prepare and calculates the backgound for wave
!makeIC            : Makes an IC for wave
!wave              : The wave program.


!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!!!!!!!!!!!!!!!!COMMENTS!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!     r... is in real space, f... in fourier space

